from distutils.core import setup

setup(
    name="justatest",
    version="1.0.0",
    py_modules=["justatest"],
    author="lillian lu",
    author_email="luxiaoqin_cm@163.com",
    description="Just a test",
    )
